// This work is licensed under the Creative Commons Attribution-ShareAlike 4.0
// International Public License.
// Visit https://creativecommons.org/licenses/by-sa/4.0/

// Persistence Of Vision Ray Tracer ('POV-Ray') sample file (yuqk fork).

// Clock-less, real time render example: rtr_kla.pov.

//   yuqk rtr_kla.pov -cc -fn +a0.3 +am2 +r2 +w80 +h200 +rtr +kla -kc

#version unofficial 3.8; // yuqk
#if (file_exists("version.inc"))
    #include "version.inc"
#end
#if (!defined(Fork_yuqk))
    #error "This POV-Ray SDL code requires the yuqk fork."
#end
global_settings { assumed_gamma 1 }
#declare Grey50 = srgb <0.5,0.5,0.5>;
background { color Grey50 }
#declare Camera00 = camera {
    perspective
    location <0,0,-2.001>
    sky y
    angle 45
    right x*(image_width/image_height)
    look_at <0,0,0>
}
#include "functions.inc"
// Function f_sphere defined in functions.inc
// Function f_helix1 defined in functions.inc
#declare White = srgb <1,1,1>;
#declare IsoHalfSphere = isosurface {
    function { f_sphere(x,y,z,2.0) }
    contained_by { box { <-2.2,-2.2,0>,<2.2,2.2,2.2> } }
    threshold 0
    accuracy 0.0005
    max_gradient 1
    open
    pigment { color White }
    scale <1,1.2,1>
}
#declare IsoHelix1 = isosurface {
    function { f_helix1(x,y,z,4,3,0.03,0.5,1,1,0) }
    contained_by { box { <-0.7,-2.7,-0.7>,<0.7,2.7,0.7> } }
    threshold 0
    accuracy 0.0005
    max_gradient 1
    max_trace 1
    pigment { color White }
}
#declare UnionHelix = union {
    #for (I,0,59,1)
        object { IsoHelix1 rotate y*(6*I)
            translate <0,0,1000> rotate y*(6*I)
        }
    #end
    no_shadow
    no_image
    no_reflection
}
#declare CarmineRed = srgb <1,0,0.21961>;
#declare Light00 = light_source {
   <0,0,0>, CarmineRed
    projected_through { UnionHelix }
}
#declare UnionHalfSphere = union {
    #for (I,0,59,1)
        object { IsoHalfSphere translate <0,0,1000> rotate y*(6*I) }
    #end
}

//   yuqk rtr_kla.pov -cc -fn +a0.3 +am2 +r2 +w80 +h200 +rtr +kla -kc
//
// To capture frames as color pfm files at 32 bit float depth channels use:
//
//   yuqk rtr_kla.pov -cc -fn +a0.005 +am2 +r2 +w80 +h200 +rtr +rtc +kla -kc +d
//
// The rtr<frame>.pfm files can be converted to exr files with the
// openimageio-tools utility (A way to get full float exr files):
//
//   iconvert -d float rtr0000.pfm rtr0000.exr
//
// Or you can use the netpbm utilities(a) with:
//
//   pfmtopam rtr0000.pfm | pamtopnm | pnmgamma -lineartobt709 >rtr9999.pnm
//   pnmtopng rtr9999.pnm >rtr9999.png
//
// Or you can being linear files into POV-Ray and output gamma corrected pngs.
//
// (a) - I've not had luck getting iconvert inbuilt gamma correction to work
// though conversion to some formats like .jpg appear to assumed gamma 2.2 or
// gamam sRGB and do it.
//
// Use +kc (Cyclic_Animation=true) for cylic / continuous renders looping
// through cameras. Use +rtr +rtc (Real_Time_Capture=true) -kla
// (Clockless_Animation=false) to generate a single pfm output image file
// over usual output image file for any render.
//
//--- scene ---
    light_source { Light00 }
    object { UnionHalfSphere }
    #for (I,0,59,1)
        camera { Camera00 translate <0,0,1000> rotate y*(6*I) }
    #end

// SPDX-License-Identifier: CC-BY-SA-4.0
